@@ -1,33 +1,53 @@
 #' Local Reserve Map With Seasonal Kendall Results for Custom Stations
 #'
-#' Create a stylized reserve-level map of seasonal kendall results from custom station locations for use with the reserve level reporting template
+#' Create a stylized reserve-level map of seasonal kendall results from custom
+#' station locations for use with the reserve level reporting template
 #'
 #' @param stations chr string of the reserve stations to include in the map
-#' @param x_loc num vector of x coordinates for \code{stations}. East longitudes must be negative.
+#' @param x_loc num vector of x coordinates for \code{stations}. East longitudes
+#'   must be negative.
 #' @param y_loc num vector of y coordinates for \code{stations}
-#' @param sk_result vector of values denoting direction and significance of seasonal kendall results. Result should be c('inc', 'dec', 'insig') for sig. negative, no sig. results, and sig. positive result
-#' @param bbox a bounding box associated with the reserve. Must be in the format of c(X1, Y1, X2, Y2)
+#' @param sk_result vector of values denoting direction and significance of
+#'   seasonal kendall results. Result should be c('inc', 'dec', 'insig') for
+#'   sig. negative, no sig. results, and sig. positive result
+#' @param bbox a bounding box associated with the reserve. Must be in the format
+#'   of c(X1, Y1, X2, Y2)
 #' @param shp {sf} data frame (preferred) or SpatialPolygons object
-#' @param station_labs logical, should stations be labeled? Defaults to \code{TRUE}
-#' @param lab_loc chr vector of 'R' and 'L', one letter for each station. if no \code{lab_loc} is specified then labels will default to the left.
-## #' @param scale_pos a vector of x and y values for scalebar location, *e.g.*, `c( "left", "bottom")`, the default.  Enter `scale_pos = NULL` for none. See `help(tm_scale_bar` for additional options.
-#' @param zoom zoom level, 1-21 for OpenStreetMaps maps. Default is to autoscale based on bbox. Higher numbers give more detail.
-#' @param maptype stamen map type from OpenStreetMap::openmap. Theoretically one of c("osm", "osm-bw","maptoolkit-topo", "waze", "bing", "stamen-toner", "stamen-terrain", "stamen-watercolor", "osm-german", "osm-wanderreitkarte", "mapbox", "esri", "esri-topo", "nps", "apple-iphoto", "skobbler", "hillshade", "opencyclemap", "osm-transport", "osm-public-transport", "osm-bbike", "osm-bbike-german").  However, many of these may not work. "stamen-toner", "stamen-terrain", and "bing" seem to work well.
+#' @param station_labs logical, should stations be labeled? Defaults to
+#'   \code{TRUE}
+#' @param lab_loc chr vector of 'R' and 'L', one letter for each station. if no
+#'   \code{lab_loc} is specified then labels will default to the left.
+#' @param bg_map a georeferenced \code{ggmap} or \code{ggplot} object used as a
+#'   background map, generally provided by a call to \code{\link{base_map}}. If
+#'   \code{bg_map} is specified, \code{maptype} and \code{zoom} are ignored.
+#' @param maptype Background map type from Stamen Maps
+#'   (\url{http://maps.stamen.com/}); one of c("terrain", "terrain-background",
+#'   "terrain-labels", "terrain-lines", "toner", "toner-2010", "toner-2011",
+#'   "toner-background", "toner-hybrid", "toner-labels", "toner-lines",
+#'   "toner-lite", "watercolor").
+#' @param zoom Zoom level for the base map created when \code{bg_map} is not
+#'   specified.  An integer value, 5 - 15, with higher numbers providing  more
+#'   detail.  If not provided, a zoom level is autoscaled based on \code{bbox}
+#'   parameters.
 #'
-#' @importFrom OpenStreetMap openmap
 #' @importFrom magrittr "%>%"
 #' @importFrom methods as
 #' @importFrom rlang .data
 #' @importFrom sf st_as_sf st_bbox st_crs st_transform
-#' @importFrom tmap tm_symbols tm_polygons tm_rgb tm_scale_bar tm_shape tm_text
-#' @importFrom tmaptools read_osm
 #' @importFrom utils download.file unzip
 #'
 #' @export
 #'
-#' @details Creates a stylized, reserve-level base map for displaying seasonal kendall results from \code{\link{sk_seasonal}}. The user can specify the reserve and stations to plot. The user can also specify a bounding box. For multi-component reserves, the user should specify a bounding box that highlights the component of interest.
+#' @details Creates a stylized, reserve-level base map for displaying seasonal
+#'   kendall results from \code{\link{sk_seasonal}}. The user can specify the
+#'   reserve and stations to plot. The user can also specify a bounding box. For
+#'   multi-component reserves, the user should specify a bounding box that
+#'   highlights the component of interest.
+#'
+#'   To display seasonal trends, the user must specify \code{c('inc', 'dec',
+#'   'insig', 'insuff')} for each station listed in the \code{stations}
+#'   argument.
 #'
-#' To display seasonal trends, the user must specify \code{c('inc', 'dec', 'insig', 'insuff')} for each station listed in the \code{stations} argument.
 #'
 #'
 #' @author Julie Padilla, Dave Eslinger
@@ -42,16 +62,16 @@
 #' x_coords <- c(-121.735281, -121.750369)
 #' y_coords <- c(36.850377, 36.806667)
 #' shp_fl <- elk_spatial
-#' bounding_elk <- c(-121.810978, 36.868218, -121.708667, 36.764050)
+#' bounding_elk <- c(-121.8005, 36.7779, -121.6966, 36.8799)
 #' lab_dir <- c('R', 'L')
 #' trnds <- c('inc', 'dec')
 #'
 #' ### Low zoom and default maptype plot (for CRAN testing, not recommended)
 #' #    Lower zoom number gives coarser text and fewer features
-#' x_low <- res_custom_sk_map(stations = stns, x_loc = x_coords,
+#' (x_low <- res_custom_sk_map(stations = stns, x_loc = x_coords,
 #'                   sk_result = trnds, y_loc = y_coords,
 #'                   bbox = bounding_elk, lab_loc = lab_dir,
-#'                   shp = shp_fl, zoom = 10)
+#'                   shp = shp_fl, zoom = 10))
 #' \donttest{
 #' ### Default zoom and maptype plot
 #' x_def <- res_custom_sk_map(stations = stns, x_loc = x_coords,
@@ -72,19 +92,20 @@
 #' x_terrain <- res_custom_sk_map(stations = stns, x_loc = x_coords,
 #'                   sk_result = trnds, y_loc = y_coords,
 #'                   bbox = bounding_elk, lab_loc = lab_dir,
-#'                   shp = shp_fl, maptype = 'stamen-terrain')
+#'                   shp = shp_fl, maptype = 'terrain')
 #' }
-#
+
 res_custom_sk_map <- function(stations
-                                   , x_loc
-                                   , y_loc
-                                   , sk_result = NULL
-                                   , bbox
-                                   , shp
-                                   , station_labs = TRUE
-                                   , lab_loc = NULL
-                                   , zoom = NULL
-                          , maptype = "stamen-toner") {
+                              , x_loc
+                              , y_loc
+                              , sk_result = NULL
+                              , bbox
+                              , shp
+                              , station_labs = TRUE
+                              , lab_loc = NULL
+                              , bg_map = NULL
+                              , zoom = NULL
+                              , maptype = "toner-lite") {
 
   # define local variables  to remove `check()` warnings
   abbrev <- lab_long <- lab_lat <- NULL
@@ -152,7 +173,7 @@ res_custom_sk_map <- function(stations
   # These are the codes for the fill color, size and shape legends.
   break_vals <- c("inc", "dec", "insig", "insuff")
   fill_colors <-  c('#444E65', '#A3DFFF', '#247BA0', '#0a0a0a')
-  res_point_size <-   c(8,8,8,8)
+  res_point_size <-   c(6, 6, 6, 9)
   res_point_shape <-  c(24, 25, 21, 13)
 
   master_key <- as.data.frame(cbind(break_vals, fill_colors, res_point_size, res_point_shape))
@@ -164,35 +185,67 @@ res_custom_sk_map <- function(stations
   # use_size  <- unique(needed_keys$res_point_size)
 
   # Set background map zoom level automatically if not specified
-  if(is.null(zoom)) {
-    diag_size <- sqrt((xmax-xmin)^2 +(ymax-ymin)^2)
-    zoom <- 15 - ceiling(sqrt(10*diag_size))
-    print(paste("Zoom level calculated as", zoom, sep = " "))
-  }
+  # if(is.null(zoom)) {
+  #   diag_size <- sqrt((xmax-xmin)^2 +(ymax-ymin)^2)
+  #   zoom <- 14 - ceiling(sqrt(10*diag_size))
+  #   print(paste("Zoom level calculated as", zoom, sep = " "))
+  # }
   print(paste("maptype is ",maptype))
 
-  bg_map <- tmaptools::read_osm(bbox, type = maptype, zoom = zoom)
-  m <- tmap::tm_shape(bg_map) +
-    tmap::tm_rgb(alpha = 0.5) +
-    tmap::tm_shape(shp) +
-    tmap::tm_polygons(lwd = 2, col = 'yellow', alpha = 0.3,
-                      border.col = '#B3B300', border.alpha = 0.8) +
-    tm_shape(loc_sf) +
-    tmap::tm_symbols(size = 1.5,
-                     col = "sk_result",
-                     # border_col = "sk_result",
-                     shape = "sk_result",
-                     shapes = use_shape,
-                     palette = use_color,
-                     legend.col.show = FALSE,
-                     legend.shape.show = FALSE)
+  if(is.null(bg_map)) {
+    bg_map <- base_map(bbox, crs = st_crs(shp),
+                     maptype = maptype,
+                     zoom = zoom)
+  }
+
+  m <- bg_map +
+    geom_sf(data = shp, aes(), inherit.aes = FALSE,
+            fill = "yellow", col = '#B3B300', alpha = 0.3) +
+    ggthemes::theme_map() +
+    #    geom_sf_text(data = loc_sf, aes(), inherit.aes = FALSE) +
+    geom_sf(data = loc_sf, inherit.aes = FALSE,
+            aes(color = .data$sk_result,
+                fill = .data$sk_result,
+                shape = .data$sk_result,
+                size = .data$sk_result),
+            stroke = 2,
+            show.legend = FALSE) +
+    scale_color_manual(values = fill_colors, breaks = break_vals) +
+    scale_fill_manual(values = fill_colors, breaks = break_vals) +
+    scale_size_manual(values = res_point_size, breaks = break_vals) +
+    scale_shape_manual(values = res_point_shape, breaks = break_vals)
 
   if(station_labs) {
+    # Define lat/long for labels, based on stations, alignment, and bbox
+    loc$lab_long <- loc$Longitude + 0.045* loc$align * (bbox[3] - bbox[1])
+    loc$lab_lat <- loc$Latitude + 0.015 * (bbox[4] - bbox[2])
+
+    # convert Labels info to sf object, use lat/lon, WGS84 projection, EPSG:4326.
+    labels_sf <- loc %>%
+      select(abbrev, lab_long, lab_lat) %>%
+      sf::st_as_sf(coords = c("lab_long","lab_lat"))
+    sf::st_crs(labels_sf) <- 4326
+
     m <- m +
-      tmap::tm_text(text = "abbrev", xmod = "align", just = c("center","top"),
-                    bg.color = 'white', bg.alpha = 0.75,
-                    fontface = "bold")
+      geom_sf_label(data = labels_sf, inherit.aes = FALSE,
+                    aes(label = abbrev))
   }
 
+  m <- m +
+    coord_sf(
+      xlim = c(bbox[1], bbox[3]),
+      ylim = c(bbox[2], bbox[4]),
+      expand = FALSE,
+      crs = st_crs(shp),
+      default_crs = NULL,
+      datum = sf::st_crs(4326),
+      # label_graticule = waiver(),
+      # label_axes = waiver(),
+      lims_method = c("cross", "box", "orthogonal", "geometry_bbox"),
+      ndiscr = 100,
+      default = FALSE,
+      clip = "on"
+    )
+
   return(m)
 }
