@@ -1,32 +1,50 @@
 #' Local Reserve Map
 #'
-#' Create a stylized reserve-level map for use with the reserve level reporting template
+#' Create a stylized reserve-level map for use with the reserve level reporting
+#' template
 #'
-#' @param nerr_site_id chr string of the reserve to make, first three characters used by NERRS
+#' @param nerr_site_id chr string of the reserve to make, first three characters
+#'   used by NERRS
 #' @param stations chr string of the reserve stations to include in the map
-#' @param bbox a bounding box associated with the reserve. Must be in the format of c(X1, Y1, X2, Y2)
+#' @param bbox a bounding box associated with the reserve. Must be in the format
+#'   of c(X1, Y1, X2, Y2)
 #' @param shp {sf} data frame (preferred) or SpatialPolygons object
-#' @param station_labs logical, should stations be labeled? Defaults to \code{TRUE}
-#' @param lab_loc chr vector of 'R' and 'L', one letter for each station. if no \code{lab_loc} is specified then labels will default to the left.
-## #' @param scale_pos a vector of x and y values for scalebar location, *e.g.*, `c( "left", "bottom")`, the default.  Enter `scale_pos = NULL` for none. See `help(tm_scale_bar` for additional options.
-#' @param zoom zoom level, 1-21 for OpenStreetMaps maps. Default is to autoscale based on bbox.
-#' @param maptype stamen map type from OpenStreetMap::openmap. Theoretically one of c("osm", "osm-bw","maptoolkit-topo", "waze", "bing", "stamen-toner", "stamen-terrain", "stamen-watercolor", "osm-german", "osm-wanderreitkarte", "mapbox", "esri", "esri-topo", "nps", "apple-iphoto", "skobbler", "hillshade", "opencyclemap", "osm-transport", "osm-public-transport", "osm-bbike", "osm-bbike-german").  However, many of these may not work. "stamen-toner", "stamen-terrain", and "bing" seem to work well.
+#' @param station_labs logical, should stations be labeled? Defaults to
+#'   \code{TRUE}
+#' @param lab_loc chr vector of 'R' and 'L', one letter for each station. if no
+#'   \code{lab_loc} is specified then labels will default to the left.
+#' @param bg_map a georeferenced \code{ggmap} or \code{ggplot} object used as a
+#'   background map, generally provided by a call to \code{\link{base_map}}. If
+#'   \code{bg_map} is specified, \code{maptype} and \code{zoom} are ignored.
+#' @param maptype Background map type from Stamen Maps
+#'   (\url{http://maps.stamen.com/}); one of c("terrain", "terrain-background",
+#'   "terrain-labels", "terrain-lines", "toner", "toner-2010", "toner-2011",
+#'   "toner-background", "toner-hybrid", "toner-labels", "toner-lines",
+#'   "toner-lite", "watercolor").
+#' @param zoom Zoom level for the base map created when \code{bg_map} is not
+#'   specified.  An integer value, 5 - 15, with higher numbers providing  more
+#'   detail.  If not provided, a zoom level is autoscaled based on \code{bbox}
+#'   parameters.
+#'
 #'
-#' @importFrom OpenStreetMap openmap
 #' @importFrom magrittr "%>%"
 #' @importFrom methods as
-#' @importFrom sf st_as_sf st_bbox st_crs st_transform
-#' @importFrom tmap tm_dots tm_polygons tm_rgb tm_scale_bar tm_shape tm_text
-#' @importFrom tmaptools read_osm
+#' @importFrom sf st_as_sf st_bbox st_crs st_sfc st_transform
 #' @importFrom utils download.file unzip
 #'
 #' @export
 #'
-#' @details Creates a stylized, reserve-level base map. The user can specify the reserve and stations to plot. The user can also specify a bounding box. For multi-component reserves, the user should specify a bounding box that highlights the component of interest.
+#' @details Creates a stylized, reserve-level base map. The user can specify the
+#'   reserve and stations to plot. The user can also specify a bounding box. For
+#'   multi-component reserves, the user should specify a bounding box that
+#'   highlights the component of interest.
 #'
-#' This function does not automatically detect conflicts between station labels. The \code{lab_loc} argument allows the user to specify "R" or "L" for each station to prevent labels from conflicting with each other.
+#'   This function does not automatically detect conflicts between station
+#'   labels. The \code{lab_loc} argument allows the user to specify "R" or "L"
+#'   for each station to prevent labels from conflicting with each other.
 #'
-#' This function is intended to be used with \code{mapview::mapshot} to generate a png for the reserve-level report.
+#'   This function is intended to be used with \code{mapview::mapshot} to
+#'   generate a png for the reserve-level report.
 #'
 #' @author Julie Padilla, Dave Eslinger
 #'
@@ -44,15 +62,15 @@
 #'           to_match <- c('wq', 'met')
 #' stns <- stations[grep(paste(to_match, collapse = '|'), stations)]
 #' shp_fl <- elk_spatial
-#' bounding_elk <- c(-121.810978, 36.868218, -121.708667, 36.764050)
+#' bounding_elk <- c(-121.8005, 36.7779, -121.6966, 36.8799)
 #' lab_dir <- c('L', 'R', 'L', 'L', 'L')
 #' labs <- c('ap', 'cw', 'nm', 'sm', 'vm')
 #'
 #' ### Low zoom and default maptype plot (for CRAN testing, not recommended)
 #' #    Lower zoom number gives coarser text and fewer features
-#' x_low <- res_local_map('elk', stations = stns, bbox = bounding_elk,
+#' (x_low <- res_local_map('elk', stations = stns, bbox = bounding_elk,
 #'                    lab_loc = lab_dir, shp = shp_fl,
-#'                    zoom = 10)
+#'                    zoom = 10))
 #'
 #' \donttest{
 #' ### Default zoom and maptype
@@ -68,7 +86,7 @@
 #'             to_match <- c('wq', 'met')
 #' stns <- stations[grep(paste(to_match, collapse = '|'), stations)]
 #' shp_fl <- cbm_spatial
-#' bounding_cbm_1 <- c(-77.393, 39.741, -75.553, 38.277)
+#' bounding_cbm_1 <- c(-77.393, 38.277, -75.553, 39.741)
 #' bounding_cbm_2 <- c(-76.8,  38.7, -76.62,  38.85)
 #' lab_dir <- c('L', 'R', 'L', 'L', 'L')
 #' labs <- c('ap', 'cw', 'nm', 'sm', 'vm')
@@ -88,9 +106,10 @@ res_local_map <- function(nerr_site_id
                           , shp
                           , station_labs = TRUE
                           , lab_loc = NULL
-#                          , scale_pos = c("lower", "bottom")
+                          #                          , scale_pos = c("lower", "bottom")
+                          , bg_map = NULL
                           , zoom = NULL
-                          , maptype = "stamen-toner") {
+                          , maptype = "toner-lite") {
 
   # define local variables  to remove `check()` warnings
   abbrev <- lab_long <- lab_lat <- NULL
@@ -155,34 +174,59 @@ res_local_map <- function(nerr_site_id
   fill_colors <-  loc_sf$color #  c('#444E65', '#A3DFFF', '#247BA0', '#0a0a0a')
   break_vals <- loc_sf$abbrev #c("inc", "dec", "insig", "insuff")
 
-  # Set background map zoom level automatically if not specified
-  if(is.null(zoom)) {
-    diag_size <- sqrt((xmax-xmin)^2 +(ymax-ymin)^2)
-    zoom <- 15 - ceiling(sqrt(10*diag_size))
-    print(paste("Zoom level calculated as", zoom, sep = " "))
-  }
   print(paste("maptype is ",maptype))
 
-  bg_map <- tmaptools::read_osm(bbox, type = maptype, zoom = zoom)
-  m <- tmap::tm_shape(bg_map) +
-    tmap::tm_rgb(alpha = 0.5) +
-    tmap::tm_shape(shp) +
-    tmap::tm_polygons(lwd = 2, col = 'yellow', alpha = 0.3,
-                      border.col = '#B3B300', border.alpha = 0.8) +
-    tmap::tm_shape(loc_sf) +
-    tmap::tm_dots(size = .75, col = "color")
+  if(is.null(bg_map)) {
+    bg_map <- base_map(bbox, crs = st_crs(shp),
+                     maptype = maptype,
+                     zoom = zoom)
+  }
+
+  m <- bg_map +
+    geom_sf(data = shp, aes(), inherit.aes = FALSE,
+            fill = "yellow", col = '#B3B300', alpha = 0.3) +
+    ggthemes::theme_map() +
+    #    geom_sf_text(data = loc_sf, aes(), inherit.aes = FALSE) +
+    geom_sf(data = loc_sf, inherit.aes = FALSE,
+            aes(color = .data$abbrev,
+                fill = .data$abbrev),
+            shape = 21,
+            size = 3.8,
+            show.legend = FALSE) +
+    scale_color_manual(values = fill_colors, breaks = break_vals) +
+    scale_fill_manual(values = fill_colors, breaks = break_vals)
 
   if(station_labs) {
-    m <- m +
-      tmap::tm_text(text = "abbrev", xmod = "align", just = c("center","top"),
-                    bg.color = 'white', bg.alpha = 0.75,
-                    fontface = "bold")
-  }
-  # if(!is.null(scale_pos)) {
-  #   m <- m +
-  #     tmap::tm_scale_bar(scale_pos)
-  # }
+    # Define lat/long for labels, based on stations, alignment, and bbox
+    loc$lab_long <- loc$Longitude + 0.045* loc$align * (bbox[3] - bbox[1])
+    loc$lab_lat <- loc$Latitude + 0.015 * (bbox[4] - bbox[2])
 
+    # convert Labels info to sf object, use lat/lon, WGS84 projection, EPSG:4326.
+    labels_sf <- loc %>%
+      select(abbrev, lab_long, lab_lat) %>%
+      sf::st_as_sf(coords = c("lab_long","lab_lat"))
+    sf::st_crs(labels_sf) <- 4326
+
+    m <- m +
+      geom_sf_label(data = labels_sf, inherit.aes = FALSE,
+                    aes(label = abbrev))
+  }
+
+  m <- m +
+    coord_sf(
+      xlim = c(bbox[1], bbox[3]),
+      ylim = c(bbox[2], bbox[4]),
+      expand = FALSE,
+      crs = st_crs(shp),
+      default_crs = NULL,
+      datum = sf::st_crs(4326),
+      # label_graticule = waiver(),
+      # label_axes = waiver(),
+      lims_method = c("cross", "box", "orthogonal", "geometry_bbox"),
+      ndiscr = 100,
+      default = FALSE,
+      clip = "on"
+    )
 
   return(m)
 }
