@@ -55,22 +55,24 @@
 #' \donttest{
 ## get data, prep
 #' dat <- elksmwq
-#'
 #' dat <- qaqc(dat, qaqc_keep = c('0', '3', '5'))
 #'
-#' do_plt <- seasonal_boxplot(dat, param = 'do_mgl')
+#' x <-
+#'   seasonal_boxplot(dat, param = 'do_mgl')
 #'
-#' do_plt <- seasonal_boxplot(dat, param = 'do_mgl',
-#' target_yr = 2015,
-#' season = list(c(1,2,3), c(4,5,6), c(7,8,9), c(10, 11, 12)),
-#' season_names = c('Winter', 'Spring', 'Summer', 'Fall'),
-#' season_start = 'Spring')
+#' y <-
+#'     seasonal_boxplot(dat, param = 'do_mgl', target_yr = 2015,
+#'     season_grps = list(c(1,2,3), c(4,5,6), c(7,8,9), c(10, 11, 12)),
+#'     season_names = c('Winter', 'Spring', 'Summer', 'Fall'),
+#'     season_start = 'Spring')
 #'
-#' do_plt_min <- seasonal_boxplot(dat, param = 'do_mgl',
-#' stat_lab = 'Minimum', FUN = function(x) min(x, na.rm = TRUE))
+#' z_min <-
+#'    seasonal_boxplot(dat, param = 'do_mgl',
+#'    stat_lab = 'Minimum', FUN = function(x) min(x, na.rm = TRUE))
 #'
-#' do_plt_max <- seasonal_boxplot(dat, param = 'do_mgl',
-#' stat_lab = 'Maximum', FUN = function(x) max(x, na.rm = TRUE))
+#' z_max <-
+#'    seasonal_boxplot(dat, param = 'do_mgl',
+#'    stat_lab = 'Maximum', FUN = function(x) max(x, na.rm = TRUE))
 #' }
 
 seasonal_boxplot <- function(swmpr_in, ...) UseMethod('seasonal_boxplot')
@@ -174,7 +176,7 @@ seasonal_boxplot.swmpr <- function(swmpr_in
   # Calc summary stat defined by FUN by season and day
   dat_hist <- dat_hist %>%
     group_by(!! seas, !! dt) %>%
-    summarise(result = FUN(!! parm))
+    summarise(result = FUN(!! parm), .groups = "drop_last")
 
   # ensure all factor levels are accounted for, even if there is no data
   dat_hist <- tidyr::complete(dat_hist, !! seas)
@@ -224,7 +226,7 @@ seasonal_boxplot.swmpr <- function(swmpr_in
 
       dat_yr <- dat_yr %>%
         dplyr::group_by(!! seas, !! dt) %>%
-        dplyr::summarise(result = FUN(!! parm)) %>%
+        dplyr::summarise(result = FUN(!! parm), .groups = "drop_last") %>%
         dplyr::group_by(!! seas) %>%
         dplyr::summarise(med = stats::median(.data$result, na.rm = TRUE))
 
